from .serp_api_client import SerpApiClient
from .baidu_search import BaiduSearch
from .google_search import GoogleSearch
from .yahoo_search import YahooSearch
from .bing_search import BingSearch
from .yandex_search import YandexSearch
from .google_scholar_search import GoogleScholarSearch
from .ebay_search import EbaySearch
from .home_depot_search import HomeDepotSearch
from .youtube_search import YoutubeSearch



import random
import unittest
import os
import pprint
from serpapi import HomeDepotSearch

class TestHomeDepotSearchApi(unittest.TestCase):

		def setUp(self):
				HomeDepotSearch.SERP_API_KEY = os.getenv("API_KEY", "demo")

		@unittest.skipIf((os.getenv("API_KEY") == None), "no api_key provided")
		def test_get_json(self):
				search = HomeDepotSearch({"q": "chair"})
				data = search.get_dict()
				self.assertEqual(data["search_metadata"]["status"], "Success")
				self.assertIsNotNone(data["search_metadata"]["home_depot_url"])
				self.assertIsNotNone(data["search_metadata"]["id"])
				self.assertTrue(len(data["products"]) > 5)
				self.assertIsNotNone(data["products"][0]["title"])

		@unittest.skipIf((os.getenv("API_KEY") == None), "no api_key provided")
		def test_get_object(self):
				search = HomeDepotSearch({"q": "chair"})
				r = search.get_object()
				pp = pprint.PrettyPrinter(indent=2)
				pp.pprint(r)
				self.assertEqual(r.search_metadata.status, "Success")
				self.assertEqual(type(r.products), list)
				self.assertIsNotNone(r.products[0].title)
				self.assertIsNotNone(r.search_metadata.id)
				self.assertIsNotNone(r.search_metadata.home_depot_url)
				self.assertEqual(r.search_parameters.q, "chair")
				self.assertEqual(r.search_parameters.engine, "home_depot")
				self.assertGreater(r.search_information.total_results, 10)

if __name__ == '__main__':
		unittest.main()



from serpapi.serp_api_client import *

class YahooSearch(SerpApiClient):
    """YahooSearch enables to search yahoo and parse the result.
    ```python
    from serpapi import YahooSearch
    query = YahooSearch({"p": "coffee"})
    data = query.get_json()
    ```

    doc: https://serpapi.com/yahoo-search-api
    """

    def __init__(self, params_dict):
        super(YahooSearch, self).__init__(params_dict, YAHOO_ENGINE)

    def get_location(self, q, limit = 5):
        raise "location is not supported by Yahoo search engine at this time"



import random
import unittest
import os
import pprint
from serpapi import SerpApiClient

# This test shows how to extends SerpApiClient
#  without using search engine wrapper.
# 
class TestSerpSearchApi(unittest.TestCase):

		@unittest.skipIf((os.getenv("API_KEY") == None), "no api_key provided")
		def test_get_json(self):
				search = SerpApiClient({
					"q": "Coffee", 
					"location": "Austin,Texas", 
					"engine": "google_scholar",
					"api_key": os.getenv("API_KEY", "demo")
					})
				data = search.get_json()
				self.assertIsNotNone(data["organic_results"][0]["title"])
				pp = pprint.PrettyPrinter(indent=2)
				pp.pprint(data)

if __name__ == '__main__':
		unittest.main()
